## common

A collection of functions used throughout FilterPy, and/or functions that you
will find useful when you build your filters.

### Saver

::: bayesian_filters.common.helpers.Saver

### Discrete White Noise

::: bayesian_filters.common.discretization.Q_discrete_white_noise

### Continuous White Noise

::: bayesian_filters.common.discretization.Q_continuous_white_noise

### Van Loan Discretization

::: bayesian_filters.common.discretization.van_loan_discretization

### Linear ODE Discretization

::: bayesian_filters.common.discretization.linear_ode_discretation

### Kinematic Kalman Filter

::: bayesian_filters.common.kinematic.kinematic_kf

### Kinematic State Transition

::: bayesian_filters.common.kinematic.kinematic_state_transition

### Runge-Kutta 4th Order

::: bayesian_filters.common.helpers.runge_kutta4

### Inverse Diagonal

::: bayesian_filters.common.helpers.inv_diagonal

### Outer Product Sum

::: bayesian_filters.common.helpers.outer_product_sum
